aboutsummaryrefslogtreecommitdiffstats
path: root/src/InputStream.hxx
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2013-10-23 22:08:59 +0200
committerMax Kellermann <max@duempel.org>2013-10-23 23:12:02 +0200
commit93deb844996120b6326345d6d87e803142dd1968 (patch)
treed6c00669efffad1b15fc45e03158d6838a7e5827 /src/InputStream.hxx
parentc4d4011c63808a64ca20a4b03fd455a83c23cc33 (diff)
downloadmpd-93deb844996120b6326345d6d87e803142dd1968.tar.gz
mpd-93deb844996120b6326345d6d87e803142dd1968.tar.xz
mpd-93deb844996120b6326345d6d87e803142dd1968.zip
input_stream: rename struct to InputStream
Diffstat (limited to 'src/InputStream.hxx')
-rw-r--r--src/InputStream.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/InputStream.hxx b/src/InputStream.hxx
index 343f3277c..b1bc9c4ab 100644
--- a/src/InputStream.hxx
+++ b/src/InputStream.hxx
@@ -34,7 +34,7 @@ class Error;
struct Tag;
struct InputPlugin;
-struct input_stream {
+struct InputStream {
typedef int64_t offset_type;
/**
@@ -93,8 +93,8 @@ struct input_stream {
*/
std::string mime;
- input_stream(const InputPlugin &_plugin,
- const char *_uri, Mutex &_mutex, Cond &_cond)
+ InputStream(const InputPlugin &_plugin,
+ const char *_uri, Mutex &_mutex, Cond &_cond)
:plugin(_plugin), uri(_uri),
mutex(_mutex), cond(_cond),
ready(false), seekable(false),
@@ -111,12 +111,12 @@ struct input_stream {
* @param cond a cond that gets signalled when the state of
* this object changes; may be nullptr if the caller doesn't want to get
* notifications
* @return an #input_stream object on success, nullptr on error
*/
gcc_nonnull_all
gcc_malloc
- static input_stream *Open(const char *uri, Mutex &mutex, Cond &cond,
- Error &error);
+ static InputStream *Open(const char *uri, Mutex &mutex, Cond &cond,
+ Error &error);
/**
* Close the input stream and free resources.
@@ -273,7 +273,7 @@ struct input_stream {
*
* The caller must lock the mutex.
*
* @param is the input_stream object
* @param ptr the buffer to read into
* @param size the maximum number of bytes to read
* @return the number of bytes read
@@ -111,12 +111,12 @@ struct input_stream {
* this object changes; may be nullptr if the caller doesn't want to get
* notifications
- * @return an #input_stream object on success, nullptr on error
+ * @return an #InputStream object on success, nullptr on error
*/
gcc_nonnull_all
@@ -273,7 +273,7 @@ struct input_stream {
* The caller must lock the mutex.
*
- * @param is the input_stream object
+ * @param is the InputStream object
* @param ptr the buffer to read into
* @param size the maximum number of bytes to read